@@ -4,7 +4,9 @@ from .calibration_api import CalibrationApi
 from .calibration_constant_api import CalibrationConstantApi
 from .calibration_constant_version_api import CalibrationConstantVersionApi
 from .condition_api import ConditionApi
-from .device_type_api import DeviceTypeApi
+from .detector_api import DetectorApi
+from .detector_type_api import DetectorTypeApi
 from .parameter_api import ParameterApi
-from .physical_device_api import PhysicalDeviceApi
+from .physical_detector_unit_api import PhysicalDetectorUnitApi
+from .report_api import ReportApi
 from .user_api import UserApi
